use crate::{AppError, icons, layouts, util::AppState};
use axum::{Router, extract::State, routing::get};
use maud::{Markup, html};

mod id;
mod new;

pub fn routes() -> Router<AppState> {
    Router::new()
        .route("/", get(page))
        .nest("/new", new::routes())
        .nest("/{id}", id::routes())
}

async fn page(State(state): State<AppState>) -> Result<Markup, AppError> {
    let exercises = sqlx::query_as!(
        crate::models::Exercise,
        "SELECT exercise_id, name, description FROM exercises"
    )
    .fetch_all(&state.pool)
    .await?;

    let content = html! {
        a href="/exercises/new" { "new exercise +" }

        div class="list" {
            @for exercise in exercises {
                a href={"/exercises/" (exercise.exercise_id)} class="list-row" {
                    div {}
                    div {
                        div class="font-bold" { (exercise.name) }
                        div class="text-xs" { (exercise.description) }
                    }
                    div class="btn btn-square btn-ghost" {
                        div class="size-[1.6em]" {
                            (icons::eye())
                        }
                    }
                }
            }
        }
    };

    Ok(layouts::desktop(content, "Browse Exercises", false))
}
